﻿using Infragistics.Documents.Excel;
using Infragistics.Windows.DataPresenter.ExcelExporter;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ExcelExport
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            this.DataContext = new DataModel();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Workbook wb = new Workbook(WorkbookFormat.Excel2007);
            Worksheet ws1 = wb.Worksheets.Add("ExcelSheet1");
            Worksheet ws2 = wb.Worksheets.Add("ExcelSheet2");

            DataPresenterExcelExporter exporter = (DataPresenterExcelExporter)this.Resources["excelExporter1"];

            exporter.ExportAsync(this.xamDataGrid1, ws1);
            exporter.ExportAsync(this.xamDataGrid2, ws2);
        }

        bool sheet1Done = false;
        bool sheet2Done = false;
        private void DataPresenterExcelExporter_ExportEnded(object sender, ExportEndedEventArgs e)
        {
            if (e.CurrentWorksheet.Name == "ExcelSheet1")
            {
                sheet1Done = true;
            }
            else if (e.CurrentWorksheet.Name == "ExcelSheet2")
            {
                sheet2Done = true;
            }

            if (sheet1Done && sheet2Done)
            {
                e.CurrentWorksheet.Workbook.Save(@"..\..\Excel\out.xlsx");
                sheet1Done = false;
                sheet2Done = false;
            }
        }
    }

    public class DataModel : INotifyPropertyChanged
    {
        public DataModel()
        {
            m_gridData1 = new ObservableCollection<TestData>();

            for (int i = 0; i < 5; i++)
            {
                m_gridData1.Add(new TestData { Id = i, Test1 = i, Test2 = "Grid1 - " + i });
            }

            m_gridData2 = new ObservableCollection<TestData>();

            for (int i = 0; i < 10; i++)
            {
                m_gridData2.Add(new TestData { Id = i, Test1 = i, Test2 = "Grid2 - " + (i % 3) });
            }

            m_gridData3 = new ObservableCollection<TestData>();

            for (int i = 0; i < 15; i++)
            {
                m_gridData3.Add(new TestData { Id = i, Test1 = i, Test2 = "Grid3 - " + (i % 10) });
            }
        }


        private ObservableCollection<TestData> m_gridData1;
        public ObservableCollection<TestData> GridData1
        {
            get { return m_gridData1; }
            set
            {
                m_gridData1 = value;
                NotifyPropertyChanged("GridData1");
            }
        }

        private ObservableCollection<TestData> m_gridData2;
        public ObservableCollection<TestData> GridData2
        {
            get { return m_gridData2; }
            set
            {
                m_gridData2 = value;
                NotifyPropertyChanged("GridData2");
            }
        }

        private ObservableCollection<TestData> m_gridData3;
        public ObservableCollection<TestData> GridData3
        {
            get { return m_gridData3; }
            set
            {
                m_gridData3 = value;
                NotifyPropertyChanged("GridData3");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }
    }

    public class TestData 
    {
        public int Id { get; set; }
        public double Test1 { get; set; }
        public String Test2 { get; set; }
    }
}
